==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/SqlDatabaseResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Cosmos DB SQL database resource object
 * @property id Name of the Cosmos DB SQL database
 */
public data class SqlDatabaseResourceArgs(
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs.builder()
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlDatabaseResourceArgs].
 */
@PulumiTagMarker
public class SqlDatabaseResourceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Name of the Cosmos DB SQL database
     */
    @JvmName("uqssicnnfqjugapj")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Cosmos DB SQL database
     */
    @JvmName("tltphtilnneuhfeb")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): SqlDatabaseResourceArgs = SqlDatabaseResourceArgs(
        id = id ?: throw PulumiNullFieldException("id"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/SqlDatabaseResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Cosmos DB SQL database resource object
 * @property id Name of the Cosmos DB SQL database
 */
public data class SqlDatabaseResourceArgs(
    public val id: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.SqlDatabaseResourceArgs.builder()
            .id(id.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SqlDatabaseResourceArgs].
 */
@PulumiTagMarker
public class SqlDatabaseResourceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Name of the Cosmos DB SQL database
     */
    @JvmName("ldjqerykgeknyfyq")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Name of the Cosmos DB SQL database
     */
    @JvmName("jkrbisxualkdebur")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): SqlDatabaseResourceArgs = SqlDatabaseResourceArgs(
        id = id ?: throw PulumiNullFieldException("id"),
    )
}
